summaryrefslogtreecommitdiffstats
path: root/kpilot/conduits/malconduit/mal-factory.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/conduits/malconduit/mal-factory.cc')
-rw-r--r--kpilot/conduits/malconduit/mal-factory.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/kpilot/conduits/malconduit/mal-factory.cc b/kpilot/conduits/malconduit/mal-factory.cc
index f9a8bcaf..3e363d26 100644
--- a/kpilot/conduits/malconduit/mal-factory.cc
+++ b/kpilot/conduits/malconduit/mal-factory.cc
@@ -60,7 +60,7 @@ unsigned long version_conduit_mal = Pilot::PLUGIN_API;
//
KAboutData *MALConduitFactory::fAbout = 0L;
-MALConduitFactory::MALConduitFactory(QObject *p, const char *n) :
+MALConduitFactory::MALConduitFactory(TQObject *p, const char *n) :
KLibFactory(p,n)
{
FUNCTIONSETUP;
@@ -90,10 +90,10 @@ MALConduitFactory::~MALConduitFactory()
KPILOT_DELETE(fAbout);
}
/* virtual */ QObject *MALConduitFactory::createObject( QObject *p,
const char *n,
const char *c,
- const QStringList &a)
+ const TQStringList &a)
{
FUNCTIONSETUP;
@@ -106,7 +106,7 @@ MALConduitFactory::~MALConduitFactory()
if (qstrcmp(c,"ConduitConfigBase")==0)
{
- QWidget *w = dynamic_cast<QWidget *>(p);
+ TQWidget *w = dynamic_cast<TQWidget *>(p);
if (w)
{
@@ -90,10 +90,10 @@ MALConduitFactory::~MALConduitFactory()
KPILOT_DELETE(fAbout);
}
-/* virtual */ QObject *MALConduitFactory::createObject( QObject *p,
+/* virtual */ TQObject *MALConduitFactory::createObject( TQObject *p,
const char *n,
const char *c,